From 3150f4b2a1f0c294e438cc31ab83f66260349e34 Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <tunes@google.com>
Date: Thu, 3 Jan 2013 10:45:56 -0500
Subject: [PATCH] 2.26.52: export coerce-name again; it's not a "utility", it's
 part of the API.

---
 asdf.asd  | 2 +-
 asdf.lisp | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/asdf.asd b/asdf.asd
index 21b490cf..755e6051 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.51" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.52" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/asdf.lisp b/asdf.lisp
index fd656203..e32b6885 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.51: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -120,7 +120,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.51")
+         (asdf-version "2.26.52")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -254,7 +254,7 @@
             #:loaded-systems ; makes for annoying SLIME completion
             #:output-files-for-system-and-operation) ; obsolete ASDF-BINARY-LOCATION function
            :export
-           (#:defsystem #:find-system #:locate-system
+           (#:defsystem #:find-system #:locate-system #:coerce-name
             #:oos #:operate #:traverse #:perform-plan
             #:system-definition-pathname #:with-system-definitions
             #:search-for-system-definition #:find-component #:component-find-path
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.51: Another System Definition Facility.
+;;; This is ASDF 2.26.52: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
-- 
GitLab